News class
Represents a news item with metadata and the actual news content object.
Constructors
Properties
- fixedRank ↔ bool?
-
Indicates if the rank is fixed.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- hashId ↔ String?
-
Unique identifier of the news.
getter/setter pair
- newsObj ↔ NewsObj?
-
The core news content, including title, description, and images.
getter/setter pair
- rank ↔ int?
-
Ranking of the news item.
getter/setter pair
- readOverride ↔ bool?
-
Indicates if read status is overridden.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type ↔ String?
-
Type of news (e.g., NEWS).
getter/setter pair
- version ↔ int?
-
Version of the news entry.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts News to a JSON map.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited